forwarding

package
v0.0.0-...-a02f58f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DefaultForwardingProvider

type DefaultForwardingProvider struct {
	// contains filtered or unexported fields
}

func NewForwardingProvider

func NewForwardingProvider(fwdRule ForwardingRule) *DefaultForwardingProvider

func (*DefaultForwardingProvider) ForwardMessage

func (f *DefaultForwardingProvider) ForwardMessage(ctx context.Context, messageModel *models.MessageModel) error

based on the fowarding rules injected this does commands the communicationProvider to send messages

type DefaultForwardingRule

type DefaultForwardingRule struct {
	// contains filtered or unexported fields
}

func (*DefaultForwardingRule) GetProvidersToForwardTo

func (r *DefaultForwardingRule) GetProvidersToForwardTo(messageType string) []communication.CommunicationProvider

Default forwarding rule from task "Only forward warning messages" and an additional check for the "correct" provider

type ForwardingProvider

type ForwardingProvider interface {
	ForwardMessage(ctx context.Context, messageModel *models.MessageModel) error
}

type ForwardingRule

type ForwardingRule interface {
	GetProvidersToForwardTo(messageType string) []communication.CommunicationProvider
}

used for deciding which communication providers is used when

Jump to