Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MessageController ¶
type MessageController struct {
// contains filtered or unexported fields
}
func NewMessageController ¶
func NewMessageController(fwdProvider forwarding.ForwardingProvider) *MessageController
func (*MessageController) ForwardMessage ¶
func (m *MessageController) ForwardMessage(ctx *gin.Context)
Validates incoming model and if that was successful hands over to ForwardingProvider and then only handles potential errors from this provider No providers found to forward to -> 200 Providers forwarded to -> 204 Validation error -> 400 Any other error -> 500 + proper log in the console
Click to show internal directories.
Click to hide internal directories.